#! /usr/bin/perl -I../script ../script/expt.pl
# vi : set ts=4 sw=4:
# expt.data.in
# Driver tables for experiments.
#
# Kinds of lines:
# 	"require": earliest version of expt.pl that can run this script.
# 	"salt": a number to be mixed with permutation number and instance name
#		to derive a random number generator seed.
#	"algprefix": used to form algorithm-specific names for output files.
# 	"inputdir": directory where the input tsp files are
# 	"outputdir": directory where the output files should go
# 	"scriptdir": directory where scripts are.
# 	"bindir": directory where the lk programs are (lk.deg and lk.no_d).
# 	"program": base name of program to run (e.g. lk or lk.single);
#		The variations will be appended to this
# 	"variations": colon-separated list of things to append to "program" to
#		get the main optimizer program.
# 	"instance": perform experiments on the named TSP file.
#	"permutations": list seeds for permuting cities (0 is identity)
#	"lkargs": list of arguments that are always supplied
#	"preprocess": list preprocessing command (e.g. for cloning)
#		There can be multiple preprocessing commands, for multiple kinds of
#		runs
#
# instance line Fields, separated by colons:
#  	name of file (without .tsp) in $inputdir
#	N, the number of cities in the instance
#	option to always use with this instance. (Use -l and -u here)
#   (sequence of entries indicating number of iters to run.  
#		N is replaced by the number of vertices.)
#
# preprocess line fields, separated by colons:
#	the command to run on the file with output piped to reorderer.
#	the early suffix to put on instance name when generating output files
#	the late suffix to put on instance name when generating output files
#

require 	0.4.14
salt		64738
algprefix	wpm.		# Mark weighted perfect matching.
inputdir	../data
outputdir	../expt
scriptdir	../script
bindir		../src
program		lk
lkargs     	-v 50 -S dsort --maxdepth 50 -c nn 20 or nq 5 --matching
permutations 0:1:2:3:4:5:6:7:8:9
variations	.deg:.no_d
preprocess cat   : :  # Empty mod letters.

instance lin105:105:-l optimal 5467.0 : N
instance lin318:318:-l optimal 15763.0 : N
instance dsj1000:1000:-l optimal 8190965.0 : N
instance pcb442:442:-l optimal 23798.0 : N
instance pr1002:1002:-l optimal 112630.0 : N
instance pcb1173:1173:-l optimal 26242.0 : N
instance pr2392:2392:-l optimal 170440.0 : N
instance pcb3038:3038:-l optimal 64487.0 : N
instance fnl4461:4461:-l optimal 83697.0 : N
instance pla7397:7397:-l optimal 10482941.0 : N
instance fl3795:3795:-l optimal 12295.0 : N
